#include "demo_types.h"
#include "demo_config.h"

uint8_t sensorResults[ 6 ];
uint8_t cnt;

void systemInit()
{
    mikrobus_gpioInit( _MIKROBUS1, _MIKROBUS_INT_PIN, _GPIO_INPUT );
    mikrobus_gpioInit( _MIKROBUS1, _MIKROBUS_RST_PIN, _GPIO_OUTPUT );
    mikrobus_gpioInit( _MIKROBUS1, _MIKROBUS_CS_PIN, _GPIO_OUTPUT );
    mikrobus_spiInit( _MIKROBUS1, &_CAPTOUCH2_SPI_CFG[0] );

    mikrobus_gpioInit( _MIKROBUS2, _MIKROBUS_AN_PIN, _GPIO_OUTPUT );
    mikrobus_gpioInit( _MIKROBUS2, _MIKROBUS_RST_PIN, _GPIO_OUTPUT );
    mikrobus_gpioInit( _MIKROBUS2, _MIKROBUS_CS_PIN, _GPIO_OUTPUT );
    mikrobus_gpioInit( _MIKROBUS2, _MIKROBUS_PWM_PIN, _GPIO_OUTPUT );
    mikrobus_spiInit( _MIKROBUS2, &_C7X10Y_SPI_CFG[0] );

    mikrobus_logInit( _MIKROBUS2, 9600 );
    mikrobus_logWrite( "Initializing...", _LOG_LINE );
}

void applicationInit()
{
    captouch2_spiDriverInit( (T_CAPTOUCH2_P)&_MIKROBUS1_GPIO, (T_CAPTOUCH2_P)&_MIKROBUS1_SPI );
    c7x10y_spiDriverInit( (T_C7X10Y_P)&_MIKROBUS2_GPIO, (T_C7X10Y_P)&_MIKROBUS2_SPI );
    c7x10y_clearDisplay();

    captouch2_reset();
    captouch2_writeReg( _CAPTOUCH2_LED_BEHAVIOR2_REG,_CAPTOUCH2_LED5_DIRECT_BEHAVIOR | _CAPTOUCH2_LED6_DIRECT_BEHAVIOR | _CAPTOUCH2_LED1_DIRECT_BEHAVIOR | _CAPTOUCH2_LED2_DIRECT_BEHAVIOR | _CAPTOUCH2_LED3_DIRECT_BEHAVIOR | _CAPTOUCH2_LED4_DIRECT_BEHAVIOR );
    captouch2_writeReg( _CAPTOUCH2_LED_PULSE2_PERIOD_REG, 0x08 );
    captouch2_writeReg( _CAPTOUCH2_LED_CONFIG_REG, _CAPTOUCH2_PULSE2_1_PULSE );
    captouch2_writeReg( _CAPTOUCH2_LED_PULSE2_DUTY_REG, _CAPTOUCH2_MIN_DUTY_0_PERCENT | _CAPTOUCH2_MAX_DUTY_100_PERCENTS );
    captouch2_writeReg( _CAPTOUCH2_LED_DIRECT_DUTY_REG, _CAPTOUCH2_MIN_DUTY_0_PERCENT | _CAPTOUCH2_MAX_DUTY_40_PERCENTS );
    captouch2_writeReg( _CAPTOUCH2_REPEAT_RATE_EN_REG, _CAPTOUCH2_INPUT4_REPEAT_RATE_EN | _CAPTOUCH2_INPUT5_REPEAT_RATE_EN | _CAPTOUCH2_INPUT6_REPEAT_RATE_EN | _CAPTOUCH2_INPUT1_REPEAT_RATE_EN | _CAPTOUCH2_INPUT2_REPEAT_RATE_EN | _CAPTOUCH2_INPUT3_REPEAT_RATE_EN );
    captouch2_writeReg( _CAPTOUCH2_CONFIG2_REG, _CAPTOUCH2_ALERT_ACTIVE_LOW | _CAPTOUCH2_SHOW_LOW_FREQ_NOISE | _CAPTOUCH2_RF_NOISE_FILTER_EN | _CAPTOUCH2_DETECT_RELEASE_EN );
    captouch2_writeReg( _CAPTOUCH2_CONFIG_REG, _CAPTOUCH2_DIG_NOISE_THRESHOLD_DIS | _CAPTOUCH2_AN_NOISE_FILTER_EN | _CAPTOUCH2_WAKE_PIN_NOT_ASSERTED );
    captouch2_writeReg( _CAPTOUCH2_SENSITIVITY_CON_REG, _CAPTOUCH2_SENSITIVITY_MULTIPLIER_32X | _CAPTOUCH2_DATA_SCALING_FACTOR_256X );
    captouch2_writeReg( _CAPTOUCH2_AVRG_AND_SAMPL_CONFIG_REG, _CAPTOUCH2_8_SAMPLES | _CAPTOUCH2_SAMPLE_TIME_1280MICROSEC | _CAPTOUCH2_CYCLE_TIME_70MILISEC );
    captouch2_writeReg( _CAPTOUCH2_SENS_IN_CONFIG2_REG, _CAPTOUCH2_PRESS_AND_HOLD_EVENT_AFTER_280MILISEC );
    captouch2_writeReg( _CAPTOUCH2_SENS_IN_CONFIG_REG, _CAPTOUCH2_5600MILISEC_BEFORE_RECALIB | _CAPTOUCH2_INTERR_REPEAT_RATE_175MILISEC );
    captouch2_setActiveMode( 1, _CAPTOUCH2_ALL_INPUTS_ENABLE );
    
    Delay_ms( 100 );
    mikrobus_logWrite( "Cap Touch 2 is initialized", _LOG_LINE );
}
void display_7x10(uint8_t num)
{
    uint8_t j;
    
    c7x10y_clearDisplay();
    c7x10y_drawNumber( num );

    for (j = 0; j < 30; j++)
    {
        c7x10y_refreshDisplay();
        Delay_ms( 1 );
    }
}

void applicationTask()
{
    captouch2_detectTouch( &sensorResults[0] );
    for (cnt = 0; cnt < 6; cnt++)
    {
        if (sensorResults[ cnt ] == 1)
        {
            if (cnt == 0)
            {
                mikrobus_logWrite( "Input 1 is touched", _LOG_LINE );
                display_7x10( 1 );
            }
            else if (cnt == 1)
            {
                mikrobus_logWrite( "Input 2 is touched", _LOG_LINE );
                display_7x10( 2 );
            }
            else if (cnt == 2)
            {
                mikrobus_logWrite( "Input 3 is touched", _LOG_LINE );
                display_7x10( 3 );
            }
            else if (cnt == 3)
            {
                mikrobus_logWrite( "Input 4 is touched", _LOG_LINE );
                display_7x10( 4 );
            }
            else if (cnt == 4)
            {
                mikrobus_logWrite( "Input 5 is touched", _LOG_LINE );
                display_7x10( 5 );
            }
            else
            {
                mikrobus_logWrite( "Input 6 is touched", _LOG_LINE );
                display_7x10( 6 );
            }
        }
    }
}


void main()
{
    systemInit();
    applicationInit();

    while (1)
    {
        applicationTask();
    }
}